@@ -36,19 +36,27 @@
 #'
 variableTypes <- function(table) {
   checkTable(table)
-  x <- dplyr::tibble(
-    variable = colnames(table),
-    type_sum = lapply(colnames(table), function(x) {
-      table %>%
-        dplyr::select(dplyr::all_of(x)) %>%
-        utils::head(1) %>%
-        dplyr::pull() %>%
-        pillar::type_sum()
-    }) %>% unlist()
-  ) %>%
-    dplyr::mutate(variable_type = assertClassification(
-      .data$type_sum, .env$table
-    ))
+  if (ncol(table) > 0) {
+    x <- dplyr::tibble(
+      "variable" = colnames(table),
+      "type_sum" = lapply(colnames(table), function(x) {
+        table %>%
+          dplyr::select(dplyr::all_of(x)) %>%
+          utils::head(1) %>%
+          dplyr::pull() %>%
+          pillar::type_sum()
+      }) %>% unlist()
+    ) %>%
+      dplyr::mutate("variable_type" = assertClassification(
+        .data$type_sum, .env$table
+      ))
+  } else {
+    x <- dplyr::tibble(
+      "variable" = character(),
+      "type_sum" = character(),
+      "variable_type" = character()
+    )
+  }
   return(x)
 }
 
