@@ -13,20 +13,20 @@ test_that("addSex, works in both cohort and condition tables", {
   cdm$cohort1 <- cdm$cohort1 %>% addSex(cdm)
   cdm$condition_occurrence <- cdm$condition_occurrence %>% addSex(cdm)
   expect_true("sex" %in% colnames(cdm$cohort1))
-  expect_true(all(cdm$cohort1$sex == c("Male", "Female", "Female", "Female")))
+  expect_true(all(cdm$cohort1 %>% dplyr::pull("sex") == c("Male", "Female", "Female", "Female")))
   expect_true("sex" %in% colnames(cdm$condition_occurrence))
-  expect_true(all(cdm$condition_occurrence$sex == c("Female", "Male", "Female", "Male", "Female", "Female", "Male", "Female", "Male", "Female")))
+  expect_true(all(cdm$condition_occurrence %>% dplyr::pull("sex") == c("Female", "Male", "Female", "Male", "Female", "Female", "Male", "Female", "Male", "Female")))
 })
 
 test_that("addSex, desired result for all parameters", {
   cdm <- mockPatientProfiles(connectionDetails, seed = 27, patient_size = 10, earliest_observation_start_date = as.Date("2010-01-01"), latest_observation_start_date = as.Date("2022-01-01"))
   cdm$cohort2 <- cdm$cohort2 %>% addSex(cdm)
   expect_true("sex" %in% colnames(cdm$cohort2))
-  expect_true(all(cdm$cohort2$sex == c("Male", "Male", "Male", "Male")))
+  expect_true(all(cdm$cohort2 %>% dplyr::pull("sex") == c("Male", "Male", "Male", "Male")))
   cdm$condition_occurrence <- cdm$condition_occurrence %>% addSex(cdm, sexName = "gender")
   expect_true("gender" %in% colnames(cdm$condition_occurrence))
   expect_false("sex" %in% colnames(cdm$condition_occurrence))
-  expect_true(all(cdm$condition_occurrence$gender == c("Male", "Male", "Female", "Female", "Male", "Male", "Male", "Male", "Female", "Female")))
+  expect_true(all(cdm$condition_occurrence %>% dplyr::pull("gender") == c("Male", "Male", "Female", "Female", "Male", "Male", "Male", "Male", "Female", "Female")))
 })
 
 test_that("different names", {
